/* GtkScintilla: Wrapper widget for the Scintilla editing component.
 *
 * Copyright (c) 2001  Michele Campeotto <micampe@micampe.it>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_SCINTILLA_H__
#define __GTK_SCINTILLA_H__

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif

#define GTK_TYPE_SCINTILLA             (gtk_scintilla_get_type ())
#define GTK_SCINTILLA(obj)             (GTK_CHECK_CAST ((obj), GTK_TYPE_SCINTILLA, GtkScintilla))
#define GTK_SCINTILLA_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_SCINTILLA, GtkScintillaClass))
#define GTK_IS_SCINTILLA(obj)          (GTK_CHECK_TYPE ((obj), GTK_TYPE_SCINTILLA))
#define GTK_IS_SCINTILLA_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_SCINTILLA))

typedef struct _GtkScintilla        GtkScintilla;
typedef struct _GtkScintillaClass   GtkScintillaClass;

struct _GtkScintilla {
    GtkFrame parent;
    
    GtkWidget *scintilla;
    
    GtkAccelGroup *accel_group;
};

struct _GtkScintillaClass {
    GtkFrameClass parent_class;

    void (* style_needed)       (GtkWidget *w, int position);
    void (* char_added)         (GtkWidget *w, int ch);
    void (* save_point_reached) (GtkWidget *w);
    void (* save_point_left)    (GtkWidget *w);
    void (* modify_attempt_ro)  (GtkWidget *w);
    void (* key)                (GtkWidget *w, int ch, int modifiers);
    void (* double_click)       (GtkWidget *w);
    void (* update_ui)          (GtkWidget *w);
    void (* modified)           (GtkWidget *w);
    void (* macro_record)       (GtkWidget *w, int message, int wparam, int lparam);
    void (* margin_click)       (GtkWidget *w, int modifiers, int position, int margin);
    void (* need_shown)         (GtkWidget *w, int position, int lenght);
    void (* painted)            (GtkWidget *w);
    void (* user_list_selection) (GtkWidget *w, int type, char *text);
    void (* uri_dropped)        (GtkWidget *w, char *text);
};

guint       gtk_scintilla_get_type          (void);
GtkWidget*  gtk_scintilla_new               (void);

long gtk_scintilla_find_text(GtkScintilla *sci, int flags, char *text,
                             long chrg_min, long chrg_max,
                             long *text_min, long *text_max);

/* --- Start of autogenerated code --- */

#define INVALID_POSITION -1
#define SCI_START 2000
#define SCI_OPTIONAL_START 3000
#define SCI_LEXER_START 4000
void gtk_scintilla_add_text(GtkScintilla *sci, int length, const char * text);
void gtk_scintilla_insert_text(GtkScintilla *sci, long pos, const char * text);
void gtk_scintilla_clear_all(GtkScintilla *sci);
void gtk_scintilla_clear_document_style(GtkScintilla *sci);
int gtk_scintilla_get_length(GtkScintilla *sci);
int gtk_scintilla_get_char_at(GtkScintilla *sci, long pos);
long gtk_scintilla_get_current_pos(GtkScintilla *sci);
long gtk_scintilla_get_anchor(GtkScintilla *sci);
int gtk_scintilla_get_style_at(GtkScintilla *sci, long pos);
void gtk_scintilla_redo(GtkScintilla *sci);
void gtk_scintilla_set_undo_collection(GtkScintilla *sci, int collect_undo);
void gtk_scintilla_select_all(GtkScintilla *sci);
void gtk_scintilla_set_save_point(GtkScintilla *sci);
int gtk_scintilla_can_redo(GtkScintilla *sci);
int gtk_scintilla_marker_line_from_handle(GtkScintilla *sci, int handle);
void gtk_scintilla_marker_delete_handle(GtkScintilla *sci, int handle);
int gtk_scintilla_get_undo_collection(GtkScintilla *sci);
#define SCWS_INVISIBLE 0
#define SCWS_VISIBLEALWAYS 1
#define SCWS_VISIBLEAFTERINDENT 2
int gtk_scintilla_get_view_ws(GtkScintilla *sci);
void gtk_scintilla_set_view_ws(GtkScintilla *sci, int view_ws);
int gtk_scintilla_position_from_point(GtkScintilla *sci, int x, int y);
int gtk_scintilla_position_from_point_close(GtkScintilla *sci, int x, int y);
void gtk_scintilla_goto_line(GtkScintilla *sci, int line);
void gtk_scintilla_goto_pos(GtkScintilla *sci, long pos);
void gtk_scintilla_set_anchor(GtkScintilla *sci, long pos_anchor);
int gtk_scintilla_get_cur_line(GtkScintilla *sci, int length, char * text);
long gtk_scintilla_get_end_styled(GtkScintilla *sci);
#define SC_EOL_CRLF 0
#define SC_EOL_CR 1
#define SC_EOL_LF 2
void gtk_scintilla_convert_eols(GtkScintilla *sci, int eol_mode);
int gtk_scintilla_get_eol_mode(GtkScintilla *sci);
void gtk_scintilla_set_eol_mode(GtkScintilla *sci, int eol_mode);
void gtk_scintilla_start_styling(GtkScintilla *sci, long pos, int mask);
void gtk_scintilla_set_styling(GtkScintilla *sci, int length, int style);
int gtk_scintilla_get_buffered_draw(GtkScintilla *sci);
void gtk_scintilla_set_buffered_draw(GtkScintilla *sci, int buffered);
void gtk_scintilla_set_tab_width(GtkScintilla *sci, int tab_width);
int gtk_scintilla_get_tab_width(GtkScintilla *sci);
#define SC_CP_UTF8 65001
void gtk_scintilla_set_code_page(GtkScintilla *sci, int code_page);
void gtk_scintilla_set_use_palette(GtkScintilla *sci, int use_palette);
#define MARKER_MAX 31
#define SC_MARK_CIRCLE 0
#define SC_MARK_ROUNDRECT 1
#define SC_MARK_ARROW 2
#define SC_MARK_SMALLRECT 3
#define SC_MARK_SHORTARROW 4
#define SC_MARK_EMPTY 5
#define SC_MARK_ARROWDOWN 6
#define SC_MARK_MINUS 7
#define SC_MARK_PLUS 8
#define SC_MARK_VLINE 9
#define SC_MARK_LCORNER 10
#define SC_MARK_TCORNER 11
#define SC_MARK_BOXPLUS 12
#define SC_MARK_BOXPLUSCONNECTED 13
#define SC_MARK_BOXMINUS 14
#define SC_MARK_BOXMINUSCONNECTED 15
#define SC_MARK_LCORNERCURVE 16
#define SC_MARK_TCORNERCURVE 17
#define SC_MARK_CIRCLEPLUS 18
#define SC_MARK_CIRCLEPLUSCONNECTED 19
#define SC_MARK_CIRCLEMINUS 20
#define SC_MARK_CIRCLEMINUSCONNECTED 21
#define SC_MARK_BACKGROUND 22
#define SC_MARK_CHARACTER 10000
#define SC_MARKNUM_FOLDEREND 25
#define SC_MARKNUM_FOLDEROPENMID 26
#define SC_MARKNUM_FOLDERMIDTAIL 27
#define SC_MARKNUM_FOLDERTAIL 28
#define SC_MARKNUM_FOLDERSUB 29
#define SC_MARKNUM_FOLDER 30
#define SC_MARKNUM_FOLDEROPEN 31
#define SC_MASK_FOLDERS 0xFE000000
void gtk_scintilla_marker_define(GtkScintilla *sci, int marker_number, int marker_symbol);
void gtk_scintilla_marker_set_fore(GtkScintilla *sci, int marker_number, long fore);
void gtk_scintilla_marker_set_back(GtkScintilla *sci, int marker_number, long back);
int gtk_scintilla_marker_add(GtkScintilla *sci, int line, int marker_number);
void gtk_scintilla_marker_delete(GtkScintilla *sci, int line, int marker_number);
void gtk_scintilla_marker_delete_all(GtkScintilla *sci, int marker_number);
int gtk_scintilla_marker_get(GtkScintilla *sci, int line);
int gtk_scintilla_marker_next(GtkScintilla *sci, int line_start, int marker_mask);
int gtk_scintilla_marker_previous(GtkScintilla *sci, int line_start, int marker_mask);
#define SC_MARGIN_SYMBOL 0
#define SC_MARGIN_NUMBER 1
void gtk_scintilla_set_margin_type_n(GtkScintilla *sci, int margin, int margin_type);
int gtk_scintilla_get_margin_type_n(GtkScintilla *sci, int margin);
void gtk_scintilla_set_margin_width_n(GtkScintilla *sci, int margin, int pixel_width);
int gtk_scintilla_get_margin_width_n(GtkScintilla *sci, int margin);
void gtk_scintilla_set_margin_mask_n(GtkScintilla *sci, int margin, int mask);
int gtk_scintilla_get_margin_mask_n(GtkScintilla *sci, int margin);
void gtk_scintilla_set_margin_sensitive_n(GtkScintilla *sci, int margin, int sensitive);
int gtk_scintilla_get_margin_sensitive_n(GtkScintilla *sci, int margin);
#define STYLE_DEFAULT 32
#define STYLE_LINENUMBER 33
#define STYLE_BRACELIGHT 34
#define STYLE_BRACEBAD 35
#define STYLE_CONTROLCHAR 36
#define STYLE_INDENTGUIDE 37
#define STYLE_LASTPREDEFINED 39
#define STYLE_MAX 127
#define SC_CHARSET_ANSI 0
#define SC_CHARSET_DEFAULT 1
#define SC_CHARSET_BALTIC 186
#define SC_CHARSET_CHINESEBIG5 136
#define SC_CHARSET_EASTEUROPE 238
#define SC_CHARSET_GB2312 134
#define SC_CHARSET_GREEK 161
#define SC_CHARSET_HANGUL 129
#define SC_CHARSET_MAC 77
#define SC_CHARSET_OEM 255
#define SC_CHARSET_RUSSIAN 204
#define SC_CHARSET_SHIFTJIS 128
#define SC_CHARSET_SYMBOL 2
#define SC_CHARSET_TURKISH 162
#define SC_CHARSET_JOHAB 130
#define SC_CHARSET_HEBREW 177
#define SC_CHARSET_ARABIC 178
#define SC_CHARSET_VIETNAMESE 163
#define SC_CHARSET_THAI 222
void gtk_scintilla_style_clear_all(GtkScintilla *sci);
void gtk_scintilla_style_set_fore(GtkScintilla *sci, int style, long fore);
void gtk_scintilla_style_set_back(GtkScintilla *sci, int style, long back);
void gtk_scintilla_style_set_bold(GtkScintilla *sci, int style, int bold);
void gtk_scintilla_style_set_italic(GtkScintilla *sci, int style, int italic);
void gtk_scintilla_style_set_size(GtkScintilla *sci, int style, int size_points);
void gtk_scintilla_style_set_font(GtkScintilla *sci, int style, const char * font_name);
void gtk_scintilla_style_set_eol_filled(GtkScintilla *sci, int style, int filled);
void gtk_scintilla_style_reset_default(GtkScintilla *sci);
void gtk_scintilla_style_set_underline(GtkScintilla *sci, int style, int underline);
#define SC_CASE_MIXED 0
#define SC_CASE_UPPER 1
#define SC_CASE_LOWER 2
void gtk_scintilla_style_set_case(GtkScintilla *sci, int style, int case_force);
void gtk_scintilla_style_set_character_set(GtkScintilla *sci, int style, int character_set);
void gtk_scintilla_set_sel_fore(GtkScintilla *sci, int use_setting, long fore);
void gtk_scintilla_set_sel_back(GtkScintilla *sci, int use_setting, long back);
void gtk_scintilla_set_caret_fore(GtkScintilla *sci, long fore);
void gtk_scintilla_clear_all_cmd_keys(GtkScintilla *sci);
void gtk_scintilla_set_styling_ex(GtkScintilla *sci, int length, const char * styles);
void gtk_scintilla_style_set_visible(GtkScintilla *sci, int style, int visible);
int gtk_scintilla_get_caret_period(GtkScintilla *sci);
void gtk_scintilla_set_caret_period(GtkScintilla *sci, int period_milliseconds);
void gtk_scintilla_set_word_chars(GtkScintilla *sci, const char * characters);
void gtk_scintilla_begin_undo_action(GtkScintilla *sci);
void gtk_scintilla_end_undo_action(GtkScintilla *sci);
#define INDIC_MAX 7
#define INDIC_PLAIN 0
#define INDIC_SQUIGGLE 1
#define INDIC_TT 2
#define INDIC_DIAGONAL 3
#define INDIC_STRIKE 4
#define INDIC0_MASK 0x20
#define INDIC1_MASK 0x40
#define INDIC2_MASK 0x80
#define INDICS_MASK 0xE0
void gtk_scintilla_indic_set_style(GtkScintilla *sci, int indic, int style);
int gtk_scintilla_indic_get_style(GtkScintilla *sci, int indic);
void gtk_scintilla_indic_set_fore(GtkScintilla *sci, int indic, long fore);
long gtk_scintilla_indic_get_fore(GtkScintilla *sci, int indic);
void gtk_scintilla_set_style_bits(GtkScintilla *sci, int bits);
int gtk_scintilla_get_style_bits(GtkScintilla *sci);
void gtk_scintilla_set_line_state(GtkScintilla *sci, int line, int state);
int gtk_scintilla_get_line_state(GtkScintilla *sci, int line);
int gtk_scintilla_get_max_line_state(GtkScintilla *sci);
int gtk_scintilla_get_caret_line_visible(GtkScintilla *sci);
void gtk_scintilla_set_caret_line_visible(GtkScintilla *sci, int show);
long gtk_scintilla_get_caret_line_back(GtkScintilla *sci);
void gtk_scintilla_set_caret_line_back(GtkScintilla *sci, long back);
void gtk_scintilla_style_set_changeable(GtkScintilla *sci, int style, int changeable);
void gtk_scintilla_autoc_show(GtkScintilla *sci, int len_entered, const char * item_list);
void gtk_scintilla_autoc_cancel(GtkScintilla *sci);
int gtk_scintilla_autoc_active(GtkScintilla *sci);
long gtk_scintilla_autoc_pos_start(GtkScintilla *sci);
void gtk_scintilla_autoc_complete(GtkScintilla *sci);
void gtk_scintilla_autoc_stops(GtkScintilla *sci, const char * character_set);
void gtk_scintilla_autoc_set_separator(GtkScintilla *sci, int separator_character);
int gtk_scintilla_autoc_get_separator(GtkScintilla *sci);
void gtk_scintilla_autoc_select(GtkScintilla *sci, const char * text);
void gtk_scintilla_autoc_set_cancel_at_start(GtkScintilla *sci, int cancel);
int gtk_scintilla_autoc_get_cancel_at_start(GtkScintilla *sci);
void gtk_scintilla_autoc_set_fill_ups(GtkScintilla *sci, const char * character_set);
void gtk_scintilla_autoc_set_choose_single(GtkScintilla *sci, int choose_single);
int gtk_scintilla_autoc_get_choose_single(GtkScintilla *sci);
void gtk_scintilla_autoc_set_ignore_case(GtkScintilla *sci, int ignore_case);
int gtk_scintilla_autoc_get_ignore_case(GtkScintilla *sci);
void gtk_scintilla_user_list_show(GtkScintilla *sci, int list_type, const char * item_list);
void gtk_scintilla_autoc_set_auto_hide(GtkScintilla *sci, int auto_hide);
int gtk_scintilla_autoc_get_auto_hide(GtkScintilla *sci);
void gtk_scintilla_autoc_set_drop_rest_of_word(GtkScintilla *sci, int drop_rest_of_word);
int gtk_scintilla_autoc_get_drop_rest_of_word(GtkScintilla *sci);
void gtk_scintilla_set_indent(GtkScintilla *sci, int indent_size);
int gtk_scintilla_get_indent(GtkScintilla *sci);
void gtk_scintilla_set_use_tabs(GtkScintilla *sci, int use_tabs);
int gtk_scintilla_get_use_tabs(GtkScintilla *sci);
void gtk_scintilla_set_line_indentation(GtkScintilla *sci, int line, int indent_size);
int gtk_scintilla_get_line_indentation(GtkScintilla *sci, int line);
long gtk_scintilla_get_line_indent_position(GtkScintilla *sci, int line);
int gtk_scintilla_get_column(GtkScintilla *sci, long pos);
void gtk_scintilla_set_h_scroll_bar(GtkScintilla *sci, int show);
int gtk_scintilla_get_h_scroll_bar(GtkScintilla *sci);
void gtk_scintilla_set_indentation_guides(GtkScintilla *sci, int show);
int gtk_scintilla_get_indentation_guides(GtkScintilla *sci);
void gtk_scintilla_set_highlight_guide(GtkScintilla *sci, int column);
int gtk_scintilla_get_highlight_guide(GtkScintilla *sci);
int gtk_scintilla_get_line_end_position(GtkScintilla *sci, int line);
int gtk_scintilla_get_code_page(GtkScintilla *sci);
long gtk_scintilla_get_caret_fore(GtkScintilla *sci);
int gtk_scintilla_get_use_palette(GtkScintilla *sci);
int gtk_scintilla_get_read_only(GtkScintilla *sci);
void gtk_scintilla_set_current_pos(GtkScintilla *sci, long pos);
void gtk_scintilla_set_selection_start(GtkScintilla *sci, long pos);
long gtk_scintilla_get_selection_start(GtkScintilla *sci);
void gtk_scintilla_set_selection_end(GtkScintilla *sci, long pos);
long gtk_scintilla_get_selection_end(GtkScintilla *sci);
void gtk_scintilla_set_print_magnification(GtkScintilla *sci, int magnification);
int gtk_scintilla_get_print_magnification(GtkScintilla *sci);
#define SC_PRINT_NORMAL 0
#define SC_PRINT_INVERTLIGHT 1
#define SC_PRINT_BLACKONWHITE 2
#define SC_PRINT_COLOURONWHITE 3
#define SC_PRINT_COLOURONWHITEDEFAULTBG 4
void gtk_scintilla_set_print_colour_mode(GtkScintilla *sci, int mode);
int gtk_scintilla_get_print_colour_mode(GtkScintilla *sci);
#define SCFIND_WHOLEWORD 2
#define SCFIND_MATCHCASE 4
#define SCFIND_WORDSTART 0x00100000
#define SCFIND_REGEXP 0x00200000
int gtk_scintilla_get_first_visible_line(GtkScintilla *sci);
int gtk_scintilla_get_line(GtkScintilla *sci, int line, char * text);
int gtk_scintilla_get_line_count(GtkScintilla *sci);
void gtk_scintilla_set_margin_left(GtkScintilla *sci, int pixel_width);
int gtk_scintilla_get_margin_left(GtkScintilla *sci);
void gtk_scintilla_set_margin_right(GtkScintilla *sci, int pixel_width);
int gtk_scintilla_get_margin_right(GtkScintilla *sci);
int gtk_scintilla_get_modify(GtkScintilla *sci);
void gtk_scintilla_set_sel(GtkScintilla *sci, long start, long end);
int gtk_scintilla_get_sel_text(GtkScintilla *sci, char * text);
void gtk_scintilla_hide_selection(GtkScintilla *sci, int normal);
int gtk_scintilla_point_x_from_position(GtkScintilla *sci, long pos);
int gtk_scintilla_point_y_from_position(GtkScintilla *sci, long pos);
int gtk_scintilla_line_from_position(GtkScintilla *sci, long pos);
int gtk_scintilla_position_from_line(GtkScintilla *sci, int line);
void gtk_scintilla_line_scroll(GtkScintilla *sci, int columns, int lines);
void gtk_scintilla_scroll_caret(GtkScintilla *sci);
void gtk_scintilla_replace_sel(GtkScintilla *sci, const char * text);
void gtk_scintilla_set_read_only(GtkScintilla *sci, int read_only);
void gtk_scintilla_null(GtkScintilla *sci);
int gtk_scintilla_can_paste(GtkScintilla *sci);
int gtk_scintilla_can_undo(GtkScintilla *sci);
void gtk_scintilla_empty_undo_buffer(GtkScintilla *sci);
void gtk_scintilla_undo(GtkScintilla *sci);
void gtk_scintilla_cut(GtkScintilla *sci);
void gtk_scintilla_copy(GtkScintilla *sci);
void gtk_scintilla_paste(GtkScintilla *sci);
void gtk_scintilla_clear(GtkScintilla *sci);
void gtk_scintilla_set_text(GtkScintilla *sci, const char * text);
int gtk_scintilla_get_text(GtkScintilla *sci, int length, char * text);
int gtk_scintilla_get_text_length(GtkScintilla *sci);
int gtk_scintilla_get_direct_function(GtkScintilla *sci);
int gtk_scintilla_get_direct_pointer(GtkScintilla *sci);
void gtk_scintilla_set_overtype(GtkScintilla *sci, int overtype);
int gtk_scintilla_get_overtype(GtkScintilla *sci);
void gtk_scintilla_set_caret_width(GtkScintilla *sci, int pixel_width);
int gtk_scintilla_get_caret_width(GtkScintilla *sci);
void gtk_scintilla_set_target_start(GtkScintilla *sci, long pos);
long gtk_scintilla_get_target_start(GtkScintilla *sci);
void gtk_scintilla_set_target_end(GtkScintilla *sci, long pos);
long gtk_scintilla_get_target_end(GtkScintilla *sci);
int gtk_scintilla_replace_target(GtkScintilla *sci, int length, const char * text);
int gtk_scintilla_replace_target_re(GtkScintilla *sci, int length, const char * text);
int gtk_scintilla_search_in_target(GtkScintilla *sci, int length, const char * text);
void gtk_scintilla_set_search_flags(GtkScintilla *sci, int flags);
int gtk_scintilla_get_search_flags(GtkScintilla *sci);
void gtk_scintilla_call_tip_show(GtkScintilla *sci, long pos, const char * definition);
void gtk_scintilla_call_tip_cancel(GtkScintilla *sci);
int gtk_scintilla_call_tip_active(GtkScintilla *sci);
long gtk_scintilla_call_tip_pos_start(GtkScintilla *sci);
void gtk_scintilla_call_tip_set_hlt(GtkScintilla *sci, int start, int end);
void gtk_scintilla_call_tip_set_back(GtkScintilla *sci, long back);
int gtk_scintilla_visible_from_doc_line(GtkScintilla *sci, int line);
int gtk_scintilla_doc_line_from_visible(GtkScintilla *sci, int line_display);
#define SC_FOLDLEVELBASE 0x400
#define SC_FOLDLEVELWHITEFLAG 0x1000
#define SC_FOLDLEVELHEADERFLAG 0x2000
#define SC_FOLDLEVELNUMBERMASK 0x0FFF
void gtk_scintilla_set_fold_level(GtkScintilla *sci, int line, int level);
int gtk_scintilla_get_fold_level(GtkScintilla *sci, int line);
int gtk_scintilla_get_last_child(GtkScintilla *sci, int line, int level);
int gtk_scintilla_get_fold_parent(GtkScintilla *sci, int line);
void gtk_scintilla_show_lines(GtkScintilla *sci, int line_start, int line_end);
void gtk_scintilla_hide_lines(GtkScintilla *sci, int line_start, int line_end);
int gtk_scintilla_get_line_visible(GtkScintilla *sci, int line);
void gtk_scintilla_set_fold_expanded(GtkScintilla *sci, int line, int expanded);
int gtk_scintilla_get_fold_expanded(GtkScintilla *sci, int line);
void gtk_scintilla_toggle_fold(GtkScintilla *sci, int line);
void gtk_scintilla_ensure_visible(GtkScintilla *sci, int line);
void gtk_scintilla_set_fold_flags(GtkScintilla *sci, int flags);
void gtk_scintilla_ensure_visible_enforce_policy(GtkScintilla *sci, int line);
void gtk_scintilla_set_tab_indents(GtkScintilla *sci, int tab_indents);
int gtk_scintilla_get_tab_indents(GtkScintilla *sci);
void gtk_scintilla_set_backspace_unindents(GtkScintilla *sci, int bs_unindents);
int gtk_scintilla_get_backspace_unindents(GtkScintilla *sci);
#define SC_TIME_FOREVER 10000000
void gtk_scintilla_set_mouse_dwell_time(GtkScintilla *sci, int period_milliseconds);
int gtk_scintilla_get_mouse_dwell_time(GtkScintilla *sci);
int gtk_scintilla_word_start_position(GtkScintilla *sci, long pos);
int gtk_scintilla_word_end_position(GtkScintilla *sci, long pos);
#define SC_WRAP_NONE 0
#define SC_WRAP_WORD 1
void gtk_scintilla_set_wrap_mode(GtkScintilla *sci, int mode);
int gtk_scintilla_get_wrap_mode(GtkScintilla *sci);
void gtk_scintilla_line_down(GtkScintilla *sci);
void gtk_scintilla_line_down_extend(GtkScintilla *sci);
void gtk_scintilla_line_up(GtkScintilla *sci);
void gtk_scintilla_line_up_extend(GtkScintilla *sci);
void gtk_scintilla_char_left(GtkScintilla *sci);
void gtk_scintilla_char_left_extend(GtkScintilla *sci);
void gtk_scintilla_char_right(GtkScintilla *sci);
void gtk_scintilla_char_right_extend(GtkScintilla *sci);
void gtk_scintilla_word_left(GtkScintilla *sci);
void gtk_scintilla_word_left_extend(GtkScintilla *sci);
void gtk_scintilla_word_right(GtkScintilla *sci);
void gtk_scintilla_word_right_extend(GtkScintilla *sci);
void gtk_scintilla_home(GtkScintilla *sci);
void gtk_scintilla_home_extend(GtkScintilla *sci);
void gtk_scintilla_line_end(GtkScintilla *sci);
void gtk_scintilla_line_end_extend(GtkScintilla *sci);
void gtk_scintilla_document_start(GtkScintilla *sci);
void gtk_scintilla_document_start_extend(GtkScintilla *sci);
void gtk_scintilla_document_end(GtkScintilla *sci);
void gtk_scintilla_document_end_extend(GtkScintilla *sci);
void gtk_scintilla_page_up(GtkScintilla *sci);
void gtk_scintilla_page_up_extend(GtkScintilla *sci);
void gtk_scintilla_page_down(GtkScintilla *sci);
void gtk_scintilla_page_down_extend(GtkScintilla *sci);
void gtk_scintilla_edit_toggle_overtype(GtkScintilla *sci);
void gtk_scintilla_cancel(GtkScintilla *sci);
void gtk_scintilla_delete_back(GtkScintilla *sci);
void gtk_scintilla_tab(GtkScintilla *sci);
void gtk_scintilla_back_tab(GtkScintilla *sci);
void gtk_scintilla_new_line(GtkScintilla *sci);
void gtk_scintilla_form_feed(GtkScintilla *sci);
void gtk_scintilla_v_c_home(GtkScintilla *sci);
void gtk_scintilla_v_c_home_extend(GtkScintilla *sci);
void gtk_scintilla_zoom_in(GtkScintilla *sci);
void gtk_scintilla_zoom_out(GtkScintilla *sci);
void gtk_scintilla_del_word_left(GtkScintilla *sci);
void gtk_scintilla_del_word_right(GtkScintilla *sci);
void gtk_scintilla_line_cut(GtkScintilla *sci);
void gtk_scintilla_line_delete(GtkScintilla *sci);
void gtk_scintilla_line_transpose(GtkScintilla *sci);
void gtk_scintilla_lower_case(GtkScintilla *sci);
void gtk_scintilla_upper_case(GtkScintilla *sci);
void gtk_scintilla_line_scroll_down(GtkScintilla *sci);
void gtk_scintilla_line_scroll_up(GtkScintilla *sci);
void gtk_scintilla_delete_back_not_line(GtkScintilla *sci);
void gtk_scintilla_move_caret_inside_view(GtkScintilla *sci);
int gtk_scintilla_line_length(GtkScintilla *sci, int line);
void gtk_scintilla_brace_highlight(GtkScintilla *sci, long pos1, long pos2);
void gtk_scintilla_brace_bad_light(GtkScintilla *sci, long pos);
long gtk_scintilla_brace_match(GtkScintilla *sci, long pos);
int gtk_scintilla_get_view_eol(GtkScintilla *sci);
void gtk_scintilla_set_view_eol(GtkScintilla *sci, int visible);
int gtk_scintilla_get_doc_pointer(GtkScintilla *sci);
void gtk_scintilla_set_doc_pointer(GtkScintilla *sci, int pointer);
void gtk_scintilla_set_mod_event_mask(GtkScintilla *sci, int mask);
#define EDGE_NONE 0
#define EDGE_LINE 1
#define EDGE_BACKGROUND 2
int gtk_scintilla_get_edge_column(GtkScintilla *sci);
void gtk_scintilla_set_edge_column(GtkScintilla *sci, int column);
int gtk_scintilla_get_edge_mode(GtkScintilla *sci);
void gtk_scintilla_set_edge_mode(GtkScintilla *sci, int mode);
long gtk_scintilla_get_edge_colour(GtkScintilla *sci);
void gtk_scintilla_set_edge_colour(GtkScintilla *sci, long edge_colour);
void gtk_scintilla_search_anchor(GtkScintilla *sci);
int gtk_scintilla_search_next(GtkScintilla *sci, int flags, const char * text);
int gtk_scintilla_search_prev(GtkScintilla *sci, int flags, const char * text);
#define CARET_SLOP 0x01
#define CARET_CENTER 0x02
#define CARET_STRICT 0x04
#define CARET_XEVEN 0x08
#define CARET_XJUMPS 0x10
void gtk_scintilla_set_caret_policy(GtkScintilla *sci, int caret_policy, int caret_slop);
int gtk_scintilla_lines_on_screen(GtkScintilla *sci);
void gtk_scintilla_use_pop_up(GtkScintilla *sci, int allow_pop_up);
int gtk_scintilla_selection_is_rectangle(GtkScintilla *sci);
void gtk_scintilla_set_zoom(GtkScintilla *sci, int zoom);
int gtk_scintilla_get_zoom(GtkScintilla *sci);
int gtk_scintilla_create_document(GtkScintilla *sci);
void gtk_scintilla_add_ref_document(GtkScintilla *sci, int doc);
void gtk_scintilla_release_document(GtkScintilla *sci, int doc);
int gtk_scintilla_get_mod_event_mask(GtkScintilla *sci);
void gtk_scintilla_set_focus(GtkScintilla *sci, int focus);
int gtk_scintilla_get_focus(GtkScintilla *sci);
void gtk_scintilla_set_status(GtkScintilla *sci, int status_code);
int gtk_scintilla_get_status(GtkScintilla *sci);
void gtk_scintilla_set_mouse_down_captures(GtkScintilla *sci, int captures);
int gtk_scintilla_get_mouse_down_captures(GtkScintilla *sci);
#define SC_CURSORNORMAL -1
#define SC_CURSORWAIT 3
void gtk_scintilla_set_cursor(GtkScintilla *sci, int cursor_type);
int gtk_scintilla_get_cursor(GtkScintilla *sci);
void gtk_scintilla_set_control_char_symbol(GtkScintilla *sci, int symbol);
int gtk_scintilla_get_control_char_symbol(GtkScintilla *sci);
void gtk_scintilla_word_part_left(GtkScintilla *sci);
void gtk_scintilla_word_part_left_extend(GtkScintilla *sci);
void gtk_scintilla_word_part_right(GtkScintilla *sci);
void gtk_scintilla_word_part_right_extend(GtkScintilla *sci);
#define VISIBLE_SLOP 0x01
#define VISIBLE_STRICT 0x04
void gtk_scintilla_set_visible_policy(GtkScintilla *sci, int visible_policy, int visible_slop);
void gtk_scintilla_del_line_left(GtkScintilla *sci);
void gtk_scintilla_del_line_right(GtkScintilla *sci);
void gtk_scintilla_set_x_offset(GtkScintilla *sci, int new_offset);
int gtk_scintilla_get_x_offset(GtkScintilla *sci);
void gtk_scintilla_grab_focus(GtkScintilla *sci);
void gtk_scintilla_start_record(GtkScintilla *sci);
void gtk_scintilla_stop_record(GtkScintilla *sci);
void gtk_scintilla_set_lexer(GtkScintilla *sci, int lexer);
int gtk_scintilla_get_lexer(GtkScintilla *sci);
void gtk_scintilla_colourise(GtkScintilla *sci, long start, long end);
void gtk_scintilla_set_property(GtkScintilla *sci, const char * key, const char * value);
void gtk_scintilla_set_keywords(GtkScintilla *sci, int keyword_set, const char * key_words);
void gtk_scintilla_set_lexer_language(GtkScintilla *sci, const char * language);
#define SC_MOD_INSERTTEXT 0x1
#define SC_MOD_DELETETEXT 0x2
#define SC_MOD_CHANGESTYLE 0x4
#define SC_MOD_CHANGEFOLD 0x8
#define SC_PERFORMED_USER 0x10
#define SC_PERFORMED_UNDO 0x20
#define SC_PERFORMED_REDO 0x40
#define SC_LASTSTEPINUNDOREDO 0x100
#define SC_MOD_CHANGEMARKER 0x200
#define SC_MOD_BEFOREINSERT 0x400
#define SC_MOD_BEFOREDELETE 0x800
#define SC_MODEVENTMASKALL 0xF77
#define SCEN_CHANGE 768
#define SCEN_SETFOCUS 512
#define SCEN_KILLFOCUS 256
#define SCK_DOWN 300
#define SCK_UP 301
#define SCK_LEFT 302
#define SCK_RIGHT 303
#define SCK_HOME 304
#define SCK_END 305
#define SCK_PRIOR 306
#define SCK_NEXT 307
#define SCK_DELETE 308
#define SCK_INSERT 309
#define SCK_ESCAPE 7
#define SCK_BACK 8
#define SCK_TAB 9
#define SCK_RETURN 13
#define SCK_ADD 310
#define SCK_SUBTRACT 311
#define SCK_DIVIDE 312
#define SCMOD_SHIFT 1
#define SCMOD_CTRL 2
#define SCMOD_ALT 4
#define SCLEX_CONTAINER 0
#define SCLEX_NULL 1
#define SCLEX_PYTHON 2
#define SCLEX_CPP 3
#define SCLEX_HTML 4
#define SCLEX_XML 5
#define SCLEX_PERL 6
#define SCLEX_SQL 7
#define SCLEX_VB 8
#define SCLEX_PROPERTIES 9
#define SCLEX_ERRORLIST 10
#define SCLEX_MAKEFILE 11
#define SCLEX_BATCH 12
#define SCLEX_XCODE 13
#define SCLEX_LATEX 14
#define SCLEX_LUA 15
#define SCLEX_DIFF 16
#define SCLEX_CONF 17
#define SCLEX_PASCAL 18
#define SCLEX_AVE 19
#define SCLEX_ADA 20
#define SCLEX_LISP 21
#define SCLEX_RUBY 22
#define SCLEX_EIFFEL 23
#define SCLEX_EIFFELKW 24
#define SCLEX_TCL 25
#define SCLEX_NNCRONTAB 26
#define SCLEX_BULLANT 27
#define SCLEX_VBSCRIPT 28
#define SCLEX_ASP 29
#define SCLEX_PHP 30
#define SCLEX_BAAN 31
#define SCLEX_AUTOMATIC 1000
#define SCE_P_DEFAULT 0
#define SCE_P_COMMENTLINE 1
#define SCE_P_NUMBER 2
#define SCE_P_STRING 3
#define SCE_P_CHARACTER 4
#define SCE_P_WORD 5
#define SCE_P_TRIPLE 6
#define SCE_P_TRIPLEDOUBLE 7
#define SCE_P_CLASSNAME 8
#define SCE_P_DEFNAME 9
#define SCE_P_OPERATOR 10
#define SCE_P_IDENTIFIER 11
#define SCE_P_COMMENTBLOCK 12
#define SCE_P_STRINGEOL 13
#define SCE_C_DEFAULT 0
#define SCE_C_COMMENT 1
#define SCE_C_COMMENTLINE 2
#define SCE_C_COMMENTDOC 3
#define SCE_C_NUMBER 4
#define SCE_C_WORD 5
#define SCE_C_STRING 6
#define SCE_C_CHARACTER 7
#define SCE_C_UUID 8
#define SCE_C_PREPROCESSOR 9
#define SCE_C_OPERATOR 10
#define SCE_C_IDENTIFIER 11
#define SCE_C_STRINGEOL 12
#define SCE_C_VERBATIM 13
#define SCE_C_REGEX 14
#define SCE_C_COMMENTLINEDOC 15
#define SCE_C_WORD2 16
#define SCE_C_COMMENTDOCKEYWORD 17
#define SCE_C_COMMENTDOCKEYWORDERROR 18
#define SCE_B_DEFAULT 0
#define SCE_B_COMMENT 1
#define SCE_B_NUMBER 2
#define SCE_B_KEYWORD 3
#define SCE_B_STRING 4
#define SCE_B_PREPROCESSOR 5
#define SCE_B_OPERATOR 6
#define SCE_B_IDENTIFIER 7
#define SCE_B_DATE 8
#define SCE_H_DEFAULT 0
#define SCE_H_TAG 1
#define SCE_H_TAGUNKNOWN 2
#define SCE_H_ATTRIBUTE 3
#define SCE_H_ATTRIBUTEUNKNOWN 4
#define SCE_H_NUMBER 5
#define SCE_H_DOUBLESTRING 6
#define SCE_H_SINGLESTRING 7
#define SCE_H_OTHER 8
#define SCE_H_COMMENT 9
#define SCE_H_ENTITY 10
#define SCE_H_TAGEND 11
#define SCE_H_XMLSTART 12
#define SCE_H_XMLEND 13
#define SCE_H_SCRIPT 14
#define SCE_H_ASP 15
#define SCE_H_ASPAT 16
#define SCE_H_CDATA 17
#define SCE_H_QUESTION 18
#define SCE_H_VALUE 19
#define SCE_H_XCCOMMENT 20
#define SCE_H_SGML_DEFAULT 21
#define SCE_H_SGML_COMMAND 22
#define SCE_H_SGML_1ST_PARAM 23
#define SCE_H_SGML_DOUBLESTRING 24
#define SCE_H_SGML_SIMPLESTRING 25
#define SCE_H_SGML_ERROR 26
#define SCE_H_SGML_SPECIAL 27
#define SCE_H_SGML_ENTITY 28
#define SCE_H_SGML_COMMENT 29
#define SCE_H_SGML_1ST_PARAM_COMMENT 30
#define SCE_H_SGML_BLOCK_DEFAULT 31
#define SCE_HJ_START 40
#define SCE_HJ_DEFAULT 41
#define SCE_HJ_COMMENT 42
#define SCE_HJ_COMMENTLINE 43
#define SCE_HJ_COMMENTDOC 44
#define SCE_HJ_NUMBER 45
#define SCE_HJ_WORD 46
#define SCE_HJ_KEYWORD 47
#define SCE_HJ_DOUBLESTRING 48
#define SCE_HJ_SINGLESTRING 49
#define SCE_HJ_SYMBOLS 50
#define SCE_HJ_STRINGEOL 51
#define SCE_HJ_REGEX 52
#define SCE_HJA_START 55
#define SCE_HJA_DEFAULT 56
#define SCE_HJA_COMMENT 57
#define SCE_HJA_COMMENTLINE 58
#define SCE_HJA_COMMENTDOC 59
#define SCE_HJA_NUMBER 60
#define SCE_HJA_WORD 61
#define SCE_HJA_KEYWORD 62
#define SCE_HJA_DOUBLESTRING 63
#define SCE_HJA_SINGLESTRING 64
#define SCE_HJA_SYMBOLS 65
#define SCE_HJA_STRINGEOL 66
#define SCE_HJA_REGEX 67
#define SCE_HB_START 70
#define SCE_HB_DEFAULT 71
#define SCE_HB_COMMENTLINE 72
#define SCE_HB_NUMBER 73
#define SCE_HB_WORD 74
#define SCE_HB_STRING 75
#define SCE_HB_IDENTIFIER 76
#define SCE_HB_STRINGEOL 77
#define SCE_HBA_START 80
#define SCE_HBA_DEFAULT 81
#define SCE_HBA_COMMENTLINE 82
#define SCE_HBA_NUMBER 83
#define SCE_HBA_WORD 84
#define SCE_HBA_STRING 85
#define SCE_HBA_IDENTIFIER 86
#define SCE_HBA_STRINGEOL 87
#define SCE_HP_START 90
#define SCE_HP_DEFAULT 91
#define SCE_HP_COMMENTLINE 92
#define SCE_HP_NUMBER 93
#define SCE_HP_STRING 94
#define SCE_HP_CHARACTER 95
#define SCE_HP_WORD 96
#define SCE_HP_TRIPLE 97
#define SCE_HP_TRIPLEDOUBLE 98
#define SCE_HP_CLASSNAME 99
#define SCE_HP_DEFNAME 100
#define SCE_HP_OPERATOR 101
#define SCE_HP_IDENTIFIER 102
#define SCE_HPA_START 105
#define SCE_HPA_DEFAULT 106
#define SCE_HPA_COMMENTLINE 107
#define SCE_HPA_NUMBER 108
#define SCE_HPA_STRING 109
#define SCE_HPA_CHARACTER 110
#define SCE_HPA_WORD 111
#define SCE_HPA_TRIPLE 112
#define SCE_HPA_TRIPLEDOUBLE 113
#define SCE_HPA_CLASSNAME 114
#define SCE_HPA_DEFNAME 115
#define SCE_HPA_OPERATOR 116
#define SCE_HPA_IDENTIFIER 117
#define SCE_HPHP_DEFAULT 118
#define SCE_HPHP_HSTRING 119
#define SCE_HPHP_SIMPLESTRING 120
#define SCE_HPHP_WORD 121
#define SCE_HPHP_NUMBER 122
#define SCE_HPHP_VARIABLE 123
#define SCE_HPHP_COMMENT 124
#define SCE_HPHP_COMMENTLINE 125
#define SCE_HPHP_HSTRING_VARIABLE 126
#define SCE_HPHP_OPERATOR 127
#define SCE_PL_DEFAULT 0
#define SCE_PL_ERROR 1
#define SCE_PL_COMMENTLINE 2
#define SCE_PL_POD 3
#define SCE_PL_NUMBER 4
#define SCE_PL_WORD 5
#define SCE_PL_STRING 6
#define SCE_PL_CHARACTER 7
#define SCE_PL_PUNCTUATION 8
#define SCE_PL_PREPROCESSOR 9
#define SCE_PL_OPERATOR 10
#define SCE_PL_IDENTIFIER 11
#define SCE_PL_SCALAR 12
#define SCE_PL_ARRAY 13
#define SCE_PL_HASH 14
#define SCE_PL_SYMBOLTABLE 15
#define SCE_PL_REGEX 17
#define SCE_PL_REGSUBST 18
#define SCE_PL_LONGQUOTE 19
#define SCE_PL_BACKTICKS 20
#define SCE_PL_DATASECTION 21
#define SCE_PL_HERE_DELIM 22
#define SCE_PL_HERE_Q 23
#define SCE_PL_HERE_QQ 24
#define SCE_PL_HERE_QX 25
#define SCE_PL_STRING_Q 26
#define SCE_PL_STRING_QQ 27
#define SCE_PL_STRING_QX 28
#define SCE_PL_STRING_QR 29
#define SCE_PL_STRING_QW 30
#define SCE_L_DEFAULT 0
#define SCE_L_COMMAND 1
#define SCE_L_TAG 2
#define SCE_L_MATH 3
#define SCE_L_COMMENT 4
#define SCE_LUA_DEFAULT 0
#define SCE_LUA_COMMENT 1
#define SCE_LUA_COMMENTLINE 2
#define SCE_LUA_COMMENTDOC 3
#define SCE_LUA_NUMBER 4
#define SCE_LUA_WORD 5
#define SCE_LUA_STRING 6
#define SCE_LUA_CHARACTER 7
#define SCE_LUA_LITERALSTRING 8
#define SCE_LUA_PREPROCESSOR 9
#define SCE_LUA_OPERATOR 10
#define SCE_LUA_IDENTIFIER 11
#define SCE_LUA_STRINGEOL 12
#define SCE_ERR_DEFAULT 0
#define SCE_ERR_PYTHON 1
#define SCE_ERR_GCC 2
#define SCE_ERR_MS 3
#define SCE_ERR_CMD 4
#define SCE_ERR_BORLAND 5
#define SCE_ERR_PERL 6
#define SCE_ERR_NET 7
#define SCE_ERR_LUA 8
#define SCE_ERR_DIFF_CHANGED 10
#define SCE_ERR_DIFF_ADDITION 11
#define SCE_ERR_DIFF_DELETION 12
#define SCE_ERR_DIFF_MESSAGE 13
#define SCE_BAT_DEFAULT 0
#define SCE_BAT_COMMENT 1
#define SCE_BAT_WORD 2
#define SCE_BAT_LABEL 3
#define SCE_BAT_HIDE 4
#define SCE_BAT_COMMAND 5
#define SCE_BAT_IDENTIFIER 6
#define SCE_BAT_OPERATOR 7
#define SCE_MAKE_DEFAULT 0
#define SCE_MAKE_COMMENT 1
#define SCE_MAKE_PREPROCESSOR 2
#define SCE_MAKE_IDENTIFIER 3
#define SCE_MAKE_OPERATOR 4
#define SCE_MAKE_TARGET 5
#define SCE_MAKE_IDEOL 9
#define SCE_CONF_DEFAULT 0
#define SCE_CONF_COMMENT 1
#define SCE_CONF_NUMBER 2
#define SCE_CONF_IDENTIFIER 3
#define SCE_CONF_EXTENSION 4
#define SCE_CONF_PARAMETER 5
#define SCE_CONF_STRING 6
#define SCE_CONF_OPERATOR 7
#define SCE_CONF_IP 8
#define SCE_CONF_DIRECTIVE 9
#define SCE_AVE_DEFAULT 0
#define SCE_AVE_COMMENT 1
#define SCE_AVE_NUMBER 2
#define SCE_AVE_WORD 3
#define SCE_AVE_KEYWORD 4
#define SCE_AVE_STATEMENT 5
#define SCE_AVE_STRING 6
#define SCE_AVE_ENUM 7
#define SCE_AVE_STRINGEOL 8
#define SCE_AVE_IDENTIFIER 9
#define SCE_AVE_OPERATOR 10
#define SCE_ADA_DEFAULT 0
#define SCE_ADA_COMMENT 1
#define SCE_ADA_NUMBER 2
#define SCE_ADA_WORD 3
#define SCE_ADA_STRING 4
#define SCE_ADA_CHARACTER 5
#define SCE_ADA_OPERATOR 6
#define SCE_ADA_IDENTIFIER 7
#define SCE_ADA_STRINGEOL 8
#define SCE_BAAN_DEFAULT 0
#define SCE_BAAN_COMMENT 1
#define SCE_BAAN_COMMENTDOC 2
#define SCE_BAAN_NUMBER 3
#define SCE_BAAN_WORD 4
#define SCE_BAAN_STRING 5
#define SCE_BAAN_PREPROCESSOR 6
#define SCE_BAAN_OPERATOR 7
#define SCE_BAAN_IDENTIFIER 8
#define SCE_BAAN_STRINGEOL 9
#define SCE_BAAN_WORD2 10
#define SCE_LISP_DEFAULT 0
#define SCE_LISP_COMMENT 1
#define SCE_LISP_NUMBER 2
#define SCE_LISP_KEYWORD 3
#define SCE_LISP_STRING 6
#define SCE_LISP_STRINGEOL 8
#define SCE_LISP_IDENTIFIER 9
#define SCE_LISP_OPERATOR 10
#define SCE_EIFFEL_DEFAULT 0
#define SCE_EIFFEL_COMMENTLINE 1
#define SCE_EIFFEL_NUMBER 2
#define SCE_EIFFEL_WORD 3
#define SCE_EIFFEL_STRING 4
#define SCE_EIFFEL_CHARACTER 5
#define SCE_EIFFEL_OPERATOR 6
#define SCE_EIFFEL_IDENTIFIER 7
#define SCE_EIFFEL_STRINGEOL 8
#define SCE_NNCRONTAB_DEFAULT 0
#define SCE_NNCRONTAB_COMMENT 1
#define SCE_NNCRONTAB_TASK 2
#define SCE_NNCRONTAB_SECTION 3
#define SCE_NNCRONTAB_KEYWORD 4
#define SCE_NNCRONTAB_MODIFIER 5
#define SCE_NNCRONTAB_ASTERISK 6
#define SCE_NNCRONTAB_NUMBER 7
#define SCE_NNCRONTAB_STRING 8
#define SCE_NNCRONTAB_ENVIRONMENT 9
#define SCE_NNCRONTAB_IDENTIFIER 10

/* --- End of autogenerated code --- */

#ifdef __cplusplus
}
#endif

#endif				/* __GTK_SCINTILLA_H__ */
